Class: Google::Apis::ArtifactregistryV1::BatchDeleteVersionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

The request to delete multiple versions across a repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchDeleteVersionsRequest

Returns a new instance of BatchDeleteVersionsRequest.



217
218
219
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 217

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#namesArray<String>

Required. The names of the versions to delete. The maximum number of versions deleted per batch is determined by the service and is dependent on the available resources in the region. Corresponds to the JSON property names

Returns:

  • (Array<String>)


209
210
211
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 209

def names
  @names
end

#validate_onlyBoolean Also known as: validate_only?

If true, the request is performed without deleting data, following AIP-163. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


214
215
216
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 214

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



222
223
224
225
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 222

def update!(**args)
  @names = args[:names] if args.key?(:names)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end