Class: Google::Apis::ArtifactregistryV1::CleanupPolicyCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

CleanupPolicyCondition is a set of conditions attached to a CleanupPolicy. If multiple entries are set, all must be satisfied for the condition to be satisfied.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CleanupPolicyCondition

Returns a new instance of CleanupPolicyCondition.



418
419
420
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#newer_thanString

Match versions newer than a duration. Corresponds to the JSON property newerThan

Returns:

  • (String)


391
392
393
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 391

def newer_than
  @newer_than
end

#older_thanString

Match versions older than a duration. Corresponds to the JSON property olderThan

Returns:

  • (String)


396
397
398
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 396

def older_than
  @older_than
end

#package_name_prefixesArray<String>

Match versions by package prefix. Applied on any prefix match. Corresponds to the JSON property packageNamePrefixes

Returns:

  • (Array<String>)


401
402
403
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 401

def package_name_prefixes
  @package_name_prefixes
end

#tag_prefixesArray<String>

Match versions by tag prefix. Applied on any prefix match. Corresponds to the JSON property tagPrefixes

Returns:

  • (Array<String>)


406
407
408
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 406

def tag_prefixes
  @tag_prefixes
end

#tag_stateString

Match versions by tag status. Corresponds to the JSON property tagState

Returns:

  • (String)


411
412
413
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 411

def tag_state
  @tag_state
end

#version_name_prefixesArray<String>

Match versions by version name prefix. Applied on any prefix match. Corresponds to the JSON property versionNamePrefixes

Returns:

  • (Array<String>)


416
417
418
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 416

def version_name_prefixes
  @version_name_prefixes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



423
424
425
426
427
428
429
430
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 423

def update!(**args)
  @newer_than = args[:newer_than] if args.key?(:newer_than)
  @older_than = args[:older_than] if args.key?(:older_than)
  @package_name_prefixes = args[:package_name_prefixes] if args.key?(:package_name_prefixes)
  @tag_prefixes = args[:tag_prefixes] if args.key?(:tag_prefixes)
  @tag_state = args[:tag_state] if args.key?(:tag_state)
  @version_name_prefixes = args[:version_name_prefixes] if args.key?(:version_name_prefixes)
end