Class: Google::Apis::ArtifactregistryV1::DockerImage
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::DockerImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
DockerImage represents a docker artifact. The following fields are returned as untyped metadata in the Version resource, using camelcase keys (i.e. metadata. imageSizeBytes): * imageSizeBytes * mediaType * buildTime
Instance Attribute Summary collapse
-
#artifact_type ⇒ String
ArtifactType of this image, e.g.
-
#build_time ⇒ String
The time this image was built.
-
#image_manifests ⇒ Array<Google::Apis::ArtifactregistryV1::ImageManifest>
Optional.
-
#image_size_bytes ⇒ Fixnum
Calculated size of the image.
-
#media_type ⇒ String
Media type of this image, e.g.
-
#name ⇒ String
Required.
-
#tags ⇒ Array<String>
Tags attached to this image.
-
#update_time ⇒ String
Output only.
-
#upload_time ⇒ String
Time the image was uploaded.
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DockerImage
constructor
A new instance of DockerImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DockerImage
Returns a new instance of DockerImage.
608 609 610 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_type ⇒ String
ArtifactType of this image, e.g. "application/vnd.example+type". If the
subject_digest is set and no artifact_type is given, the media_type will
be considered as the artifact_type. This field is returned as the metadata.
artifactType field in the Version resource.
Corresponds to the JSON property artifactType
544 545 546 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 544 def artifact_type @artifact_type end |
#build_time ⇒ String
The time this image was built. This field is returned as the 'metadata.
buildTime' field in the Version resource. The build time is returned to the
client as an RFC 3339 string, which can be easily used with the JavaScript
Date constructor.
Corresponds to the JSON property buildTime
552 553 554 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 552 def build_time @build_time end |
#image_manifests ⇒ Array<Google::Apis::ArtifactregistryV1::ImageManifest>
Optional. For multi-arch images (manifest lists), this field contains the list
of image manifests.
Corresponds to the JSON property imageManifests
558 559 560 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 558 def image_manifests @image_manifests end |
#image_size_bytes ⇒ Fixnum
Calculated size of the image. This field is returned as the 'metadata.
imageSizeBytes' field in the Version resource.
Corresponds to the JSON property imageSizeBytes
564 565 566 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 564 def image_size_bytes @image_size_bytes end |
#media_type ⇒ String
Media type of this image, e.g. "application/vnd.docker.distribution.manifest.
v2+json". This field is returned as the 'metadata.mediaType' field in the
Version resource.
Corresponds to the JSON property mediaType
571 572 573 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 571 def media_type @media_type end |
#name ⇒ String
Required. registry_location, project_id, repository_name and image id forms a
unique image name:projects//locations//repositories//dockerImages/. For
example, "projects/test-project/locations/us-west4/repositories/test-repo/
dockerImages/ nginx@sha256:
e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf", where "us-
west4" is the registry_location, "test-project" is the project_id, "test-repo"
is the repository_name and "nginx@sha256:
e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf" is the image'
s digest.
Corresponds to the JSON property name
584 585 586 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 584 def name @name end |
#tags ⇒ Array<String>
Tags attached to this image.
Corresponds to the JSON property tags
589 590 591 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 589 def @tags end |
#update_time ⇒ String
Output only. The time when the docker image was last updated.
Corresponds to the JSON property updateTime
594 595 596 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 594 def update_time @update_time end |
#upload_time ⇒ String
Time the image was uploaded.
Corresponds to the JSON property uploadTime
599 600 601 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 599 def upload_time @upload_time end |
#uri ⇒ String
Required. URL to access the image. Example: us-west4-docker.pkg.dev/test-
project/test-repo/nginx@sha256:
e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf
Corresponds to the JSON property uri
606 607 608 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 606 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
613 614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 613 def update!(**args) @artifact_type = args[:artifact_type] if args.key?(:artifact_type) @build_time = args[:build_time] if args.key?(:build_time) @image_manifests = args[:image_manifests] if args.key?(:image_manifests) @image_size_bytes = args[:image_size_bytes] if args.key?(:image_size_bytes) @media_type = args[:media_type] if args.key?(:media_type) @name = args[:name] if args.key?(:name) @tags = args[:tags] if args.key?(:tags) @update_time = args[:update_time] if args.key?(:update_time) @upload_time = args[:upload_time] if args.key?(:upload_time) @uri = args[:uri] if args.key?(:uri) end |