Class: Google::Apis::ArtifactregistryV1::DockerRepositoryConfig
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::DockerRepositoryConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
DockerRepositoryConfig is docker related repository details. Provides additional configuration details for repositories of the docker format type.
Instance Attribute Summary collapse
-
#immutable_tags ⇒ Boolean
(also: #immutable_tags?)
The repository which enabled this flag prevents all tags from being modified, moved or deleted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DockerRepositoryConfig
constructor
A new instance of DockerRepositoryConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DockerRepositoryConfig
Returns a new instance of DockerRepositoryConfig.
611 612 613 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 611 def initialize(**args) update!(**args) end |
Instance Attribute Details
#immutable_tags ⇒ Boolean Also known as:
The repository which enabled this flag prevents all tags from being modified,
moved or deleted. This does not prevent tags from being created.
Corresponds to the JSON property immutableTags
608 609 610 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 608 def @immutable_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
616 617 618 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 616 def update!(**args) @immutable_tags = args[:immutable_tags] if args.key?(:immutable_tags) end |