Class: Google::Apis::ArtifactregistryV1::ExportArtifactResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

The response for exporting an artifact to a destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportArtifactResponse

Returns a new instance of ExportArtifactResponse.



702
703
704
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exported_versionGoogle::Apis::ArtifactregistryV1::Version

The body of a version resource. A version resource represents a collection of components, such as files and other data. This may correspond to a version in many package management schemes. Corresponds to the JSON property exportedVersion



700
701
702
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 700

def exported_version
  @exported_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



707
708
709
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 707

def update!(**args)
  @exported_version = args[:exported_version] if args.key?(:exported_version)
end