Class: Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1File
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1File
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
Files store content that is potentially associated with Packages or Versions.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#fetch_time ⇒ String
Output only.
-
#hashes ⇒ Array<Google::Apis::ArtifactregistryV1::HashProp>
The hashes of the file content.
-
#name ⇒ String
The name of the file, for example:
projects/p1/locations/us-central1/ repositories/repo1/files/a%2Fb%2Fc.txt. -
#owner ⇒ String
The name of the Package or Version that owns this file, if any.
-
#size_bytes ⇒ Fixnum
The size of the File in bytes.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsArtifactregistryV1File
constructor
A new instance of GoogleDevtoolsArtifactregistryV1File.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsArtifactregistryV1File
Returns a new instance of GoogleDevtoolsArtifactregistryV1File.
1022 1023 1024 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Client specified annotations.
Corresponds to the JSON property annotations
982 983 984 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 982 def annotations @annotations end |
#create_time ⇒ String
Output only. The time when the File was created.
Corresponds to the JSON property createTime
987 988 989 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 987 def create_time @create_time end |
#fetch_time ⇒ String
Output only. The time when the last attempt to refresh the file's data was
made. Only set when the repository is remote.
Corresponds to the JSON property fetchTime
993 994 995 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 993 def fetch_time @fetch_time end |
#hashes ⇒ Array<Google::Apis::ArtifactregistryV1::HashProp>
The hashes of the file content.
Corresponds to the JSON property hashes
998 999 1000 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 998 def hashes @hashes end |
#name ⇒ String
The name of the file, for example: projects/p1/locations/us-central1/
repositories/repo1/files/a%2Fb%2Fc.txt. If the file ID part contains slashes,
they are escaped.
Corresponds to the JSON property name
1005 1006 1007 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1005 def name @name end |
#owner ⇒ String
The name of the Package or Version that owns this file, if any.
Corresponds to the JSON property owner
1010 1011 1012 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1010 def owner @owner end |
#size_bytes ⇒ Fixnum
The size of the File in bytes.
Corresponds to the JSON property sizeBytes
1015 1016 1017 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1015 def size_bytes @size_bytes end |
#update_time ⇒ String
Output only. The time when the File was last updated.
Corresponds to the JSON property updateTime
1020 1021 1022 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1020 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1027 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @fetch_time = args[:fetch_time] if args.key?(:fetch_time) @hashes = args[:hashes] if args.key?(:hashes) @name = args[:name] if args.key?(:name) @owner = args[:owner] if args.key?(:owner) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @update_time = args[:update_time] if args.key?(:update_time) end |