Class: Google::Apis::ArtifactregistryV1::ImportAptArtifactsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::ImportAptArtifactsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
The request to import new apt artifacts.
Instance Attribute Summary collapse
-
#gcs_source ⇒ Google::Apis::ArtifactregistryV1::ImportAptArtifactsGcsSource
Google Cloud Storage location where the artifacts currently reside.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportAptArtifactsRequest
constructor
A new instance of ImportAptArtifactsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportAptArtifactsRequest
Returns a new instance of ImportAptArtifactsRequest.
1385 1386 1387 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1385 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_source ⇒ Google::Apis::ArtifactregistryV1::ImportAptArtifactsGcsSource
Google Cloud Storage location where the artifacts currently reside.
Corresponds to the JSON property gcsSource
1383 1384 1385 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1383 def gcs_source @gcs_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1390 1391 1392 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1390 def update!(**args) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) end |