Class: Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
The response message from importing artifacts.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsErrorInfo>
Detailed error info for packages that were not imported.
-
#googet_artifacts ⇒ Array<Google::Apis::ArtifactregistryV1::GoogetArtifact>
The GooGet artifacts updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportGoogetArtifactsResponse
constructor
A new instance of ImportGoogetArtifactsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportGoogetArtifactsResponse
Returns a new instance of ImportGoogetArtifactsResponse.
1522 1523 1524 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1522 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsErrorInfo>
Detailed error info for packages that were not imported.
Corresponds to the JSON property errors
1515 1516 1517 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1515 def errors @errors end |
#googet_artifacts ⇒ Array<Google::Apis::ArtifactregistryV1::GoogetArtifact>
The GooGet artifacts updated.
Corresponds to the JSON property googetArtifacts
1520 1521 1522 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1520 def googet_artifacts @googet_artifacts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1527 1528 1529 1530 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1527 def update!(**args) @errors = args[:errors] if args.key?(:errors) @googet_artifacts = args[:googet_artifacts] if args.key?(:googet_artifacts) end |