Class: Google::Apis::ArtifactregistryV1::ListNpmPackagesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::ListNpmPackagesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
The response from listing npm packages.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token to retrieve the next page of artifacts, or empty if there are no more artifacts to return.
-
#npm_packages ⇒ Array<Google::Apis::ArtifactregistryV1::NpmPackage>
The npm packages returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListNpmPackagesResponse
constructor
A new instance of ListNpmPackagesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListNpmPackagesResponse
Returns a new instance of ListNpmPackagesResponse.
1819 1820 1821 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token to retrieve the next page of artifacts, or empty if there are no
more artifacts to return.
Corresponds to the JSON property nextPageToken
1812 1813 1814 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1812 def next_page_token @next_page_token end |
#npm_packages ⇒ Array<Google::Apis::ArtifactregistryV1::NpmPackage>
The npm packages returned.
Corresponds to the JSON property npmPackages
1817 1818 1819 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1817 def npm_packages @npm_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1824 1825 1826 1827 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1824 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) end |