Class: Google::Apis::ArtifactregistryV1::ListRulesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::ListRulesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
The response from listing rules.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token to retrieve the next page of rules, or empty if there are no more rules to return.
-
#rules ⇒ Array<Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1Rule>
The rules returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRulesResponse
constructor
A new instance of ListRulesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRulesResponse
Returns a new instance of ListRulesResponse.
1910 1911 1912 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token to retrieve the next page of rules, or empty if there are no more
rules to return.
Corresponds to the JSON property nextPageToken
1903 1904 1905 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1903 def next_page_token @next_page_token end |
#rules ⇒ Array<Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1Rule>
The rules returned.
Corresponds to the JSON property rules
1908 1909 1910 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1908 def rules @rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1915 1916 1917 1918 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1915 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rules = args[:rules] if args.key?(:rules) end |