Class: Google::Apis::ArtifactregistryV1::NpmRepository
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::NpmRepository
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
Configuration for a Npm remote repository.
Instance Attribute Summary collapse
-
#custom_repository ⇒ Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigNpmRepositoryCustomRepository
Customer-specified publicly available remote repository.
-
#public_repository ⇒ String
One of the publicly available Npm repositories supported by Artifact Registry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NpmRepository
constructor
A new instance of NpmRepository.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NpmRepository
Returns a new instance of NpmRepository.
2294 2295 2296 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2294 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_repository ⇒ Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigNpmRepositoryCustomRepository
Customer-specified publicly available remote repository.
Corresponds to the JSON property customRepository
2287 2288 2289 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2287 def custom_repository @custom_repository end |
#public_repository ⇒ String
One of the publicly available Npm repositories supported by Artifact Registry.
Corresponds to the JSON property publicRepository
2292 2293 2294 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2292 def public_repository @public_repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2299 2300 2301 2302 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2299 def update!(**args) @custom_repository = args[:custom_repository] if args.key?(:custom_repository) @public_repository = args[:public_repository] if args.key?(:public_repository) end |