Class: Google::Apis::ArtifactregistryV1::PlatformLogsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

The platform logs config for a project or a repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlatformLogsConfig

Returns a new instance of PlatformLogsConfig.



2361
2362
2363
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2361

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#logging_stateString

Optional. The state of the platform logs: enabled or disabled. Corresponds to the JSON property loggingState

Returns:

  • (String)


2353
2354
2355
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2353

def logging_state
  @logging_state
end

#severity_levelString

Optional. The severity level for the logs. Logs will be generated if their severity level is >= than the value of the severity level mentioned here. Corresponds to the JSON property severityLevel

Returns:

  • (String)


2359
2360
2361
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2359

def severity_level
  @severity_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2366
2367
2368
2369
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2366

def update!(**args)
  @logging_state = args[:logging_state] if args.key?(:logging_state)
  @severity_level = args[:severity_level] if args.key?(:severity_level)
end