Class: Google::Apis::ArtifactregistryV1::PrewarmArtifactRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

The request for prewarming an artifact for streaming.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrewarmArtifactRequest

Returns a new instance of PrewarmArtifactRequest.



2596
2597
2598
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2596

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

Optional. If true, old artifact will be evicted to make room for the new artifact. Corresponds to the JSON property force

Returns:

  • (Boolean)


2563
2564
2565
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2563

def force
  @force
end

#platformGoogle::Apis::ArtifactregistryV1::PrewarmPlatform

The platform (architecture and OS) of the image. This is a sub-message. Corresponds to the JSON property platform



2569
2570
2571
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2569

def platform
  @platform
end

#retention_daysFixnum

Optional. The retention days of the prewarmed artifact. If not specified, the artifact will be cached for 3 days. Corresponds to the JSON property retentionDays

Returns:

  • (Fixnum)


2575
2576
2577
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2575

def retention_days
  @retention_days
end

#stream_locationString

Optional. The location to cache the artifact in. If not specified, the artifact will be cached in the same location as the artifact. multi-region is not supported for this field. Corresponds to the JSON property streamLocation

Returns:

  • (String)


2582
2583
2584
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2582

def stream_location
  @stream_location
end

#tagString

Optional. The artifact tag Format:projects/project/locations/location/ repositories/repository/packages/package/tags/tag Corresponds to the JSON property tag

Returns:

  • (String)


2588
2589
2590
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2588

def tag
  @tag
end

#versionString

Optional. The artifact version Format: projects/project/locations/location/ repositories/repository/packages/package/versions/version Corresponds to the JSON property version

Returns:

  • (String)


2594
2595
2596
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2594

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2601
2602
2603
2604
2605
2606
2607
2608
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2601

def update!(**args)
  @force = args[:force] if args.key?(:force)
  @platform = args[:platform] if args.key?(:platform)
  @retention_days = args[:retention_days] if args.key?(:retention_days)
  @stream_location = args[:stream_location] if args.key?(:stream_location)
  @tag = args[:tag] if args.key?(:tag)
  @version = args[:version] if args.key?(:version)
end