Class: Google::Apis::ArtifactregistryV1::ProjectConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

The Artifact Registry logging configurations that apply to a Project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectConfig

Returns a new instance of ProjectConfig.



2706
2707
2708
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The name of the project's configuration. Always of the form: projects/project/locations/location/projectConfig Corresponds to the JSON property name

Returns:

  • (String)


2699
2700
2701
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2699

def name
  @name
end

#platform_logs_configGoogle::Apis::ArtifactregistryV1::PlatformLogsConfig

The platform logs config for a project or a repository. Corresponds to the JSON property platformLogsConfig



2704
2705
2706
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2704

def platform_logs_config
  @platform_logs_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2711
2712
2713
2714
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2711

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @platform_logs_config = args[:platform_logs_config] if args.key?(:platform_logs_config)
end