Class: Google::Apis::ArtifactregistryV1::ProjectSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

The Artifact Registry settings that apply to a Project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectSettings

Returns a new instance of ProjectSettings.



2724
2725
2726
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#legacy_redirection_stateString

The redirection state of the legacy repositories in this project. Corresponds to the JSON property legacyRedirectionState

Returns:

  • (String)


2710
2711
2712
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2710

def legacy_redirection_state
  @legacy_redirection_state
end

#nameString

The name of the project's settings. Always of the form: projects/project-id/ projectSettings In update request: never set In response: always set Corresponds to the JSON property name

Returns:

  • (String)


2716
2717
2718
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2716

def name
  @name
end

#pull_percentFixnum

The percentage of pull traffic to redirect from GCR to AR when using partial redirection. Corresponds to the JSON property pullPercent

Returns:

  • (Fixnum)


2722
2723
2724
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2722

def pull_percent
  @pull_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2729
2730
2731
2732
2733
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2729

def update!(**args)
  @legacy_redirection_state = args[:legacy_redirection_state] if args.key?(:legacy_redirection_state)
  @name = args[:name] if args.key?(:name)
  @pull_percent = args[:pull_percent] if args.key?(:pull_percent)
end