Class: Google::Apis::ArtifactregistryV1::RemoteRepositoryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

Remote repository configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoteRepositoryConfig

Returns a new instance of RemoteRepositoryConfig.



2893
2894
2895
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apt_repositoryGoogle::Apis::ArtifactregistryV1::AptRepository

Configuration for an Apt remote repository. Corresponds to the JSON property aptRepository



2838
2839
2840
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2838

def apt_repository
  @apt_repository
end

#common_repositoryGoogle::Apis::ArtifactregistryV1::CommonRemoteRepository

Common remote repository settings type. Corresponds to the JSON property commonRepository



2843
2844
2845
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2843

def common_repository
  @common_repository
end

#descriptionString

The description of the remote source. Corresponds to the JSON property description

Returns:

  • (String)


2848
2849
2850
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2848

def description
  @description
end

#disable_upstream_validationBoolean Also known as: disable_upstream_validation?

Input only. A create/update remote repo option to avoid making a HEAD/GET request to validate a remote repo and any supplied upstream credentials. Corresponds to the JSON property disableUpstreamValidation

Returns:

  • (Boolean)


2854
2855
2856
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2854

def disable_upstream_validation
  @disable_upstream_validation
end

#docker_repositoryGoogle::Apis::ArtifactregistryV1::DockerRepository

Configuration for a Docker remote repository. Corresponds to the JSON property dockerRepository



2860
2861
2862
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2860

def docker_repository
  @docker_repository
end

#maven_repositoryGoogle::Apis::ArtifactregistryV1::MavenRepository

Configuration for a Maven remote repository. Corresponds to the JSON property mavenRepository



2865
2866
2867
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2865

def maven_repository
  @maven_repository
end

#no_cacheGoogle::Apis::ArtifactregistryV1::NoCacheFetching

The configuration for the no-cache fetching mode, which acts as a non-caching proxy. Corresponds to the JSON property noCache



2871
2872
2873
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2871

def no_cache
  @no_cache
end

#npm_repositoryGoogle::Apis::ArtifactregistryV1::NpmRepository

Configuration for a Npm remote repository. Corresponds to the JSON property npmRepository



2876
2877
2878
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2876

def npm_repository
  @npm_repository
end

#python_repositoryGoogle::Apis::ArtifactregistryV1::PythonRepository

Configuration for a Python remote repository. Corresponds to the JSON property pythonRepository



2881
2882
2883
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2881

def python_repository
  @python_repository
end

#upstream_credentialsGoogle::Apis::ArtifactregistryV1::UpstreamCredentials

The credentials to access the remote repository. Corresponds to the JSON property upstreamCredentials



2886
2887
2888
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2886

def upstream_credentials
  @upstream_credentials
end

#yum_repositoryGoogle::Apis::ArtifactregistryV1::YumRepository

Configuration for a Yum remote repository. Corresponds to the JSON property yumRepository



2891
2892
2893
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2891

def yum_repository
  @yum_repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2898

def update!(**args)
  @apt_repository = args[:apt_repository] if args.key?(:apt_repository)
  @common_repository = args[:common_repository] if args.key?(:common_repository)
  @description = args[:description] if args.key?(:description)
  @disable_upstream_validation = args[:disable_upstream_validation] if args.key?(:disable_upstream_validation)
  @docker_repository = args[:docker_repository] if args.key?(:docker_repository)
  @maven_repository = args[:maven_repository] if args.key?(:maven_repository)
  @no_cache = args[:no_cache] if args.key?(:no_cache)
  @npm_repository = args[:npm_repository] if args.key?(:npm_repository)
  @python_repository = args[:python_repository] if args.key?(:python_repository)
  @upstream_credentials = args[:upstream_credentials] if args.key?(:upstream_credentials)
  @yum_repository = args[:yum_repository] if args.key?(:yum_repository)
end