Class: Google::Apis::ArtifactregistryV1::Repository

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

A Repository for storing artifacts with a specific format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Repository

Returns a new instance of Repository.



3099
3100
3101
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cleanup_policiesHash<String,Google::Apis::ArtifactregistryV1::CleanupPolicy>

Optional. Cleanup policies for this repository. Cleanup policies indicate when certain package versions can be automatically deleted. Map keys are policy IDs supplied by users during policy creation. They must unique within a repository and be under 128 characters in length. Corresponds to the JSON property cleanupPolicies



2977
2978
2979
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2977

def cleanup_policies
  @cleanup_policies
end

#cleanup_policy_dry_runBoolean Also known as: cleanup_policy_dry_run?

Optional. If true, the cleanup pipeline is prevented from deleting versions in this repository. Corresponds to the JSON property cleanupPolicyDryRun

Returns:

  • (Boolean)


2983
2984
2985
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2983

def cleanup_policy_dry_run
  @cleanup_policy_dry_run
end

#create_timeString

Output only. The time when the repository was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2989
2990
2991
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2989

def create_time
  @create_time
end

#descriptionString

The user-provided description of the repository. Corresponds to the JSON property description

Returns:

  • (String)


2994
2995
2996
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2994

def description
  @description
end

#disallow_unspecified_modeBoolean Also known as: disallow_unspecified_mode?

Optional. If this is true, an unspecified repo type will be treated as error rather than defaulting to standard. Corresponds to the JSON property disallowUnspecifiedMode

Returns:

  • (Boolean)


3000
3001
3002
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3000

def disallow_unspecified_mode
  @disallow_unspecified_mode
end

#docker_configGoogle::Apis::ArtifactregistryV1::DockerRepositoryConfig

DockerRepositoryConfig is docker related repository details. Provides additional configuration details for repositories of the docker format type. Corresponds to the JSON property dockerConfig



3007
3008
3009
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3007

def docker_config
  @docker_config
end

#formatString

Optional. The format of packages that are stored in the repository. Corresponds to the JSON property format

Returns:

  • (String)


3012
3013
3014
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3012

def format
  @format
end

#kms_key_nameString

The Cloud KMS resource name of the customer managed encryption key that's used to encrypt the contents of the Repository. Has the form: projects/my-project/ locations/my-region/keyRings/my-kr/cryptoKeys/my-key. This value may not be changed after the Repository has been created. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


3020
3021
3022
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3020

def kms_key_name
  @kms_key_name
end

#labelsHash<String,String>

Labels with user-defined metadata. This field may contain up to 64 entries. Label keys and values may be no longer than 63 characters. Label keys must begin with a lowercase letter and may only contain lowercase letters, numeric characters, underscores, and dashes. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3028
3029
3030
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3028

def labels
  @labels
end

#maven_configGoogle::Apis::ArtifactregistryV1::MavenRepositoryConfig

MavenRepositoryConfig is maven related repository details. Provides additional configuration details for repositories of the maven format type. Corresponds to the JSON property mavenConfig



3034
3035
3036
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3034

def maven_config
  @maven_config
end

#modeString

Optional. The mode of the repository. Corresponds to the JSON property mode

Returns:

  • (String)


3039
3040
3041
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3039

def mode
  @mode
end

#nameString

The name of the repository, for example: projects/p1/locations/us-central1/ repositories/repo1. For each location in a project, repository names must be unique. Corresponds to the JSON property name

Returns:

  • (String)


3046
3047
3048
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3046

def name
  @name
end

#platform_logs_configGoogle::Apis::ArtifactregistryV1::PlatformLogsConfig

The platform logs config for a project or a repository. Corresponds to the JSON property platformLogsConfig



3051
3052
3053
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3051

def platform_logs_config
  @platform_logs_config
end

#registry_uriString

Output only. The repository endpoint, for example: us-docker.pkg.dev/my-proj/ my-repo. Corresponds to the JSON property registryUri

Returns:

  • (String)


3057
3058
3059
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3057

def registry_uri
  @registry_uri
end

#remote_repository_configGoogle::Apis::ArtifactregistryV1::RemoteRepositoryConfig

Remote repository configuration. Corresponds to the JSON property remoteRepositoryConfig



3062
3063
3064
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3062

def remote_repository_config
  @remote_repository_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Whether or not this repository satisfies PZI. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


3067
3068
3069
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3067

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Whether or not this repository satisfies PZS. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


3073
3074
3075
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3073

def satisfies_pzs
  @satisfies_pzs
end

#size_bytesFixnum

Output only. The size, in bytes, of all artifact storage in this repository. Repositories that are generally available or in public preview use this to calculate storage costs. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


3081
3082
3083
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3081

def size_bytes
  @size_bytes
end

#update_timeString

Output only. The time when the repository was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3086
3087
3088
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3086

def update_time
  @update_time
end

#virtual_repository_configGoogle::Apis::ArtifactregistryV1::VirtualRepositoryConfig

Virtual repository configuration. Corresponds to the JSON property virtualRepositoryConfig



3091
3092
3093
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3091

def virtual_repository_config
  @virtual_repository_config
end

#vulnerability_scanning_configGoogle::Apis::ArtifactregistryV1::VulnerabilityScanningConfig

Config on whether to perform vulnerability scanning for resources in this repository, as well as output fields describing current state. Corresponds to the JSON property vulnerabilityScanningConfig



3097
3098
3099
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3097

def vulnerability_scanning_config
  @vulnerability_scanning_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3104
3105
3106
3107
3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
3125
3126
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3104

def update!(**args)
  @cleanup_policies = args[:cleanup_policies] if args.key?(:cleanup_policies)
  @cleanup_policy_dry_run = args[:cleanup_policy_dry_run] if args.key?(:cleanup_policy_dry_run)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disallow_unspecified_mode = args[:disallow_unspecified_mode] if args.key?(:disallow_unspecified_mode)
  @docker_config = args[:docker_config] if args.key?(:docker_config)
  @format = args[:format] if args.key?(:format)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @labels = args[:labels] if args.key?(:labels)
  @maven_config = args[:maven_config] if args.key?(:maven_config)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @platform_logs_config = args[:platform_logs_config] if args.key?(:platform_logs_config)
  @registry_uri = args[:registry_uri] if args.key?(:registry_uri)
  @remote_repository_config = args[:remote_repository_config] if args.key?(:remote_repository_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @update_time = args[:update_time] if args.key?(:update_time)
  @virtual_repository_config = args[:virtual_repository_config] if args.key?(:virtual_repository_config)
  @vulnerability_scanning_config = args[:vulnerability_scanning_config] if args.key?(:vulnerability_scanning_config)
end