Class: Google::Apis::ArtifactregistryV1::UsernamePasswordCredentials
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::UsernamePasswordCredentials
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
Username and password credentials.
Instance Attribute Summary collapse
-
#password_secret_version ⇒ String
The Secret Manager key version that holds the password to access the remote repository.
-
#username ⇒ String
The username to access the remote repository.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsernamePasswordCredentials
constructor
A new instance of UsernamePasswordCredentials.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsernamePasswordCredentials
Returns a new instance of UsernamePasswordCredentials.
3478 3479 3480 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#password_secret_version ⇒ String
The Secret Manager key version that holds the password to access the remote
repository. Must be in the format of projects/project/secrets/secret/
versions/version`.
Corresponds to the JSON propertypasswordSecretVersion`
3471 3472 3473 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3471 def password_secret_version @password_secret_version end |
#username ⇒ String
The username to access the remote repository.
Corresponds to the JSON property username
3476 3477 3478 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3476 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3483 3484 3485 3486 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3483 def update!(**args) @password_secret_version = args[:password_secret_version] if args.key?(:password_secret_version) @username = args[:username] if args.key?(:username) end |