Class: Google::Apis::ArtifactregistryV1::Version

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

The body of a version resource. A version resource represents a collection of components, such as files and other data. This may correspond to a version in many package management schemes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Version

Returns a new instance of Version.



3840
3841
3842
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Client specified annotations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


3796
3797
3798
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3796

def annotations
  @annotations
end

#create_timeString

The time when the version was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3801
3802
3803
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3801

def create_time
  @create_time
end

#descriptionString

Optional. Description of the version, as specified in its metadata. Corresponds to the JSON property description

Returns:

  • (String)


3806
3807
3808
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3806

def description
  @description
end

#fingerprintsArray<Google::Apis::ArtifactregistryV1::HashProp>

Output only. Immutable reference for the version, calculated based on the version's content. Currently we only support dirsum_sha256 hash algorithm. Additional hash algorithms may be added in the future. Corresponds to the JSON property fingerprints



3813
3814
3815
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3813

def fingerprints
  @fingerprints
end

#metadataHash<String,Object>

Output only. Repository-specific Metadata stored against this version. The fields returned are defined by the underlying repository-specific resource. Currently, the resources could be: DockerImage MavenArtifact Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


3820
3821
3822
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3820

def 
  @metadata
end

#nameString

The name of the version, for example: projects/p1/locations/us-central1/ repositories/repo1/packages/pkg1/versions/art1. If the package or version ID parts contain slashes, the slashes are escaped. Corresponds to the JSON property name

Returns:

  • (String)


3827
3828
3829
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3827

def name
  @name
end

Output only. A list of related tags. Will contain up to 100 tags that reference this version. Corresponds to the JSON property relatedTags



3833
3834
3835
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3833

def related_tags
  @related_tags
end

#update_timeString

The time when the version was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3838
3839
3840
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3838

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3845

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @fingerprints = args[:fingerprints] if args.key?(:fingerprints)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @related_tags = args[:related_tags] if args.key?(:related_tags)
  @update_time = args[:update_time] if args.key?(:update_time)
end