Class: Google::Apis::ArtifactregistryV1::VulnerabilityScanningConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

Config on whether to perform vulnerability scanning for resources in this repository, as well as output fields describing current state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityScanningConfig

Returns a new instance of VulnerabilityScanningConfig.



3925
3926
3927
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enablement_configString

Optional. Config for whether this repository has vulnerability scanning disabled. Corresponds to the JSON property enablementConfig

Returns:

  • (String)


3907
3908
3909
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3907

def enablement_config
  @enablement_config
end

#enablement_stateString

Output only. State of feature enablement, combining repository enablement config and API enablement state. Corresponds to the JSON property enablementState

Returns:

  • (String)


3913
3914
3915
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3913

def enablement_state
  @enablement_state
end

#enablement_state_reasonString

Output only. Reason for the repository state. Corresponds to the JSON property enablementStateReason

Returns:

  • (String)


3918
3919
3920
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3918

def enablement_state_reason
  @enablement_state_reason
end

#last_enable_timeString

Output only. The last time this repository config was enabled. Corresponds to the JSON property lastEnableTime

Returns:

  • (String)


3923
3924
3925
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3923

def last_enable_time
  @last_enable_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3930
3931
3932
3933
3934
3935
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3930

def update!(**args)
  @enablement_config = args[:enablement_config] if args.key?(:enablement_config)
  @enablement_state = args[:enablement_state] if args.key?(:enablement_state)
  @enablement_state_reason = args[:enablement_state_reason] if args.key?(:enablement_state_reason)
  @last_enable_time = args[:last_enable_time] if args.key?(:last_enable_time)
end