Class: Google::Apis::ArtifactregistryV1::BatchDeleteVersionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::BatchDeleteVersionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
The request to delete multiple versions across a repository.
Instance Attribute Summary collapse
-
#names ⇒ Array<String>
Required.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
If true, the request is performed without deleting data, following AIP-163.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchDeleteVersionsRequest
constructor
A new instance of BatchDeleteVersionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchDeleteVersionsRequest
Returns a new instance of BatchDeleteVersionsRequest.
217 218 219 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#names ⇒ Array<String>
Required. The names of the versions to delete. The maximum number of versions
deleted per batch is determined by the service and is dependent on the
available resources in the region.
Corresponds to the JSON property names
209 210 211 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 209 def names @names end |
#validate_only ⇒ Boolean Also known as: validate_only?
If true, the request is performed without deleting data, following AIP-163.
Corresponds to the JSON property validateOnly
214 215 216 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 214 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
222 223 224 225 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 222 def update!(**args) @names = args[:names] if args.key?(:names) @validate_only = args[:validate_only] if args.key?(:validate_only) end |