Class: Google::Apis::ArtifactregistryV1::DockerImage
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::DockerImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
DockerImage represents a docker artifact. The following fields are returned as untyped metadata in the Version resource, using camelcase keys (i.e. metadata. imageSizeBytes): * imageSizeBytes * mediaType * buildTime
Instance Attribute Summary collapse
-
#artifact_type ⇒ String
ArtifactType of this image, e.g.
-
#build_time ⇒ String
The time this image was built.
-
#image_manifests ⇒ Array<Google::Apis::ArtifactregistryV1::ImageManifest>
Optional.
-
#image_size_bytes ⇒ Fixnum
Calculated size of the image.
-
#media_type ⇒ String
Media type of this image, e.g.
-
#name ⇒ String
Required.
-
#tags ⇒ Array<String>
Tags attached to this image.
-
#update_time ⇒ String
Output only.
-
#upload_time ⇒ String
Time the image was uploaded.
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DockerImage
constructor
A new instance of DockerImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DockerImage
Returns a new instance of DockerImage.
554 555 556 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 554 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_type ⇒ String
ArtifactType of this image, e.g. "application/vnd.example+type". If the
subject_digest is set and no artifact_type is given, the media_type will
be considered as the artifact_type. This field is returned as the metadata.
artifactType field in the Version resource.
Corresponds to the JSON property artifactType
490 491 492 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 490 def artifact_type @artifact_type end |
#build_time ⇒ String
The time this image was built. This field is returned as the 'metadata.
buildTime' field in the Version resource. The build time is returned to the
client as an RFC 3339 string, which can be easily used with the JavaScript
Date constructor.
Corresponds to the JSON property buildTime
498 499 500 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 498 def build_time @build_time end |
#image_manifests ⇒ Array<Google::Apis::ArtifactregistryV1::ImageManifest>
Optional. For multi-arch images (manifest lists), this field contains the list
of image manifests.
Corresponds to the JSON property imageManifests
504 505 506 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 504 def image_manifests @image_manifests end |
#image_size_bytes ⇒ Fixnum
Calculated size of the image. This field is returned as the 'metadata.
imageSizeBytes' field in the Version resource.
Corresponds to the JSON property imageSizeBytes
510 511 512 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 510 def image_size_bytes @image_size_bytes end |
#media_type ⇒ String
Media type of this image, e.g. "application/vnd.docker.distribution.manifest.
v2+json". This field is returned as the 'metadata.mediaType' field in the
Version resource.
Corresponds to the JSON property mediaType
517 518 519 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 517 def media_type @media_type end |
#name ⇒ String
Required. registry_location, project_id, repository_name and image id forms a
unique image name:projects//locations//repositories//dockerImages/. For
example, "projects/test-project/locations/us-west4/repositories/test-repo/
dockerImages/ nginx@sha256:
e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf", where "us-
west4" is the registry_location, "test-project" is the project_id, "test-repo"
is the repository_name and "nginx@sha256:
e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf" is the image'
s digest.
Corresponds to the JSON property name
530 531 532 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 530 def name @name end |
#tags ⇒ Array<String>
Tags attached to this image.
Corresponds to the JSON property tags
535 536 537 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 535 def @tags end |
#update_time ⇒ String
Output only. The time when the docker image was last updated.
Corresponds to the JSON property updateTime
540 541 542 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 540 def update_time @update_time end |
#upload_time ⇒ String
Time the image was uploaded.
Corresponds to the JSON property uploadTime
545 546 547 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 545 def upload_time @upload_time end |
#uri ⇒ String
Required. URL to access the image. Example: us-west4-docker.pkg.dev/test-
project/test-repo/nginx@sha256:
e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf
Corresponds to the JSON property uri
552 553 554 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 552 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
559 560 561 562 563 564 565 566 567 568 569 570 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 559 def update!(**args) @artifact_type = args[:artifact_type] if args.key?(:artifact_type) @build_time = args[:build_time] if args.key?(:build_time) @image_manifests = args[:image_manifests] if args.key?(:image_manifests) @image_size_bytes = args[:image_size_bytes] if args.key?(:image_size_bytes) @media_type = args[:media_type] if args.key?(:media_type) @name = args[:name] if args.key?(:name) @tags = args[:tags] if args.key?(:tags) @update_time = args[:update_time] if args.key?(:update_time) @upload_time = args[:upload_time] if args.key?(:upload_time) @uri = args[:uri] if args.key?(:uri) end |