Class: Google::Apis::ArtifactregistryV1::ExportArtifactRequest
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::ExportArtifactRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
The request for exporting an artifact to a destination.
Instance Attribute Summary collapse
-
#gcs_path ⇒ String
The Cloud Storage path to export the artifact to.
-
#source_tag ⇒ String
The artifact tag to export.
-
#source_version ⇒ String
The artifact version to export.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExportArtifactRequest
constructor
A new instance of ExportArtifactRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExportArtifactRequest
Returns a new instance of ExportArtifactRequest.
679 680 681 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_path ⇒ String
The Cloud Storage path to export the artifact to. Should start with the bucket
name, and optionally have a directory path. Examples: dst_bucket,
dst_bucket/sub_dir. Existing objects with the same path will be overwritten.
Corresponds to the JSON property gcsPath
665 666 667 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 665 def gcs_path @gcs_path end |
#source_tag ⇒ String
The artifact tag to export. Format:projects/project/locations/location/
repositories/repository/packages/package/tags/tag
Corresponds to the JSON property sourceTag
671 672 673 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 671 def source_tag @source_tag end |
#source_version ⇒ String
The artifact version to export. Format: projects/project/locations/location
/repositories/repository/packages/package/versions/version
Corresponds to the JSON property sourceVersion
677 678 679 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 677 def source_version @source_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
684 685 686 687 688 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 684 def update!(**args) @gcs_path = args[:gcs_path] if args.key?(:gcs_path) @source_tag = args[:source_tag] if args.key?(:source_tag) @source_version = args[:source_version] if args.key?(:source_version) end |