Class: Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1File
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1File
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
Files store content that is potentially associated with Packages or Versions.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#fetch_time ⇒ String
Output only.
-
#hashes ⇒ Array<Google::Apis::ArtifactregistryV1::HashProp>
The hashes of the file content.
-
#name ⇒ String
The name of the file, for example:
projects/p1/locations/us-central1/ repositories/repo1/files/a%2Fb%2Fc.txt. -
#owner ⇒ String
The name of the Package or Version that owns this file, if any.
-
#size_bytes ⇒ Fixnum
The size of the File in bytes.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsArtifactregistryV1File
constructor
A new instance of GoogleDevtoolsArtifactregistryV1File.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsArtifactregistryV1File
Returns a new instance of GoogleDevtoolsArtifactregistryV1File.
968 969 970 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 968 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Client specified annotations.
Corresponds to the JSON property annotations
928 929 930 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 928 def annotations @annotations end |
#create_time ⇒ String
Output only. The time when the File was created.
Corresponds to the JSON property createTime
933 934 935 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 933 def create_time @create_time end |
#fetch_time ⇒ String
Output only. The time when the last attempt to refresh the file's data was
made. Only set when the repository is remote.
Corresponds to the JSON property fetchTime
939 940 941 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 939 def fetch_time @fetch_time end |
#hashes ⇒ Array<Google::Apis::ArtifactregistryV1::HashProp>
The hashes of the file content.
Corresponds to the JSON property hashes
944 945 946 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 944 def hashes @hashes end |
#name ⇒ String
The name of the file, for example: projects/p1/locations/us-central1/
repositories/repo1/files/a%2Fb%2Fc.txt. If the file ID part contains slashes,
they are escaped.
Corresponds to the JSON property name
951 952 953 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 951 def name @name end |
#owner ⇒ String
The name of the Package or Version that owns this file, if any.
Corresponds to the JSON property owner
956 957 958 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 956 def owner @owner end |
#size_bytes ⇒ Fixnum
The size of the File in bytes.
Corresponds to the JSON property sizeBytes
961 962 963 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 961 def size_bytes @size_bytes end |
#update_time ⇒ String
Output only. The time when the File was last updated.
Corresponds to the JSON property updateTime
966 967 968 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 966 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
973 974 975 976 977 978 979 980 981 982 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 973 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @fetch_time = args[:fetch_time] if args.key?(:fetch_time) @hashes = args[:hashes] if args.key?(:hashes) @name = args[:name] if args.key?(:name) @owner = args[:owner] if args.key?(:owner) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @update_time = args[:update_time] if args.key?(:update_time) end |