Class: Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1File
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1File
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
Files store content that is potentially associated with Packages or Versions.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#fetch_time ⇒ String
Output only.
-
#hashes ⇒ Array<Google::Apis::ArtifactregistryV1::HashProp>
The hashes of the file content.
-
#name ⇒ String
The name of the file, for example:
projects/p1/locations/us-central1/ repositories/repo1/files/a%2Fb%2Fc.txt. -
#owner ⇒ String
The name of the Package or Version that owns this file, if any.
-
#size_bytes ⇒ Fixnum
The size of the File in bytes.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsArtifactregistryV1File
constructor
A new instance of GoogleDevtoolsArtifactregistryV1File.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsArtifactregistryV1File
Returns a new instance of GoogleDevtoolsArtifactregistryV1File.
955 956 957 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Client specified annotations.
Corresponds to the JSON property annotations
915 916 917 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 915 def annotations @annotations end |
#create_time ⇒ String
Output only. The time when the File was created.
Corresponds to the JSON property createTime
920 921 922 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 920 def create_time @create_time end |
#fetch_time ⇒ String
Output only. The time when the last attempt to refresh the file's data was
made. Only set when the repository is remote.
Corresponds to the JSON property fetchTime
926 927 928 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 926 def fetch_time @fetch_time end |
#hashes ⇒ Array<Google::Apis::ArtifactregistryV1::HashProp>
The hashes of the file content.
Corresponds to the JSON property hashes
931 932 933 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 931 def hashes @hashes end |
#name ⇒ String
The name of the file, for example: projects/p1/locations/us-central1/
repositories/repo1/files/a%2Fb%2Fc.txt. If the file ID part contains slashes,
they are escaped.
Corresponds to the JSON property name
938 939 940 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 938 def name @name end |
#owner ⇒ String
The name of the Package or Version that owns this file, if any.
Corresponds to the JSON property owner
943 944 945 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 943 def owner @owner end |
#size_bytes ⇒ Fixnum
The size of the File in bytes.
Corresponds to the JSON property sizeBytes
948 949 950 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 948 def size_bytes @size_bytes end |
#update_time ⇒ String
Output only. The time when the File was last updated.
Corresponds to the JSON property updateTime
953 954 955 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 953 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
960 961 962 963 964 965 966 967 968 969 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 960 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @fetch_time = args[:fetch_time] if args.key?(:fetch_time) @hashes = args[:hashes] if args.key?(:hashes) @name = args[:name] if args.key?(:name) @owner = args[:owner] if args.key?(:owner) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @update_time = args[:update_time] if args.key?(:update_time) end |