Class: Google::Apis::ArtifactregistryV1::ImageManifest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

Details of a single image manifest within a multi-arch image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageManifest

Returns a new instance of ImageManifest.



1278
1279
1280
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Optional. The CPU architecture of the image. Values are provided by the Docker client and are not validated by Artifact Registry. Example values include " amd64", "arm64", "ppc64le", "s390x", "riscv64", "mips64le", etc. Corresponds to the JSON property architecture

Returns:

  • (String)


1240
1241
1242
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1240

def architecture
  @architecture
end

#digestString

Optional. The manifest digest, in the format "sha256:". Corresponds to the JSON property digest

Returns:

  • (String)


1245
1246
1247
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1245

def digest
  @digest
end

#media_typeString

Optional. The media type of the manifest, e.g., "application/vnd.docker. distribution.manifest.v2+json" Corresponds to the JSON property mediaType

Returns:

  • (String)


1251
1252
1253
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1251

def media_type
  @media_type
end

#osString

Optional. The operating system of the image. Values are provided by the Docker client and are not validated by Artifact Registry. Example values include " linux", "windows", "darwin", "aix", etc. Corresponds to the JSON property os

Returns:

  • (String)


1258
1259
1260
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1258

def os
  @os
end

#os_featuresArray<String>

Optional. The required OS features for the image, for example on Windows win32k. Corresponds to the JSON property osFeatures

Returns:

  • (Array<String>)


1264
1265
1266
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1264

def os_features
  @os_features
end

#os_versionString

Optional. The OS version of the image, for example on Windows 10.0.14393.1066 . Corresponds to the JSON property osVersion

Returns:

  • (String)


1270
1271
1272
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1270

def os_version
  @os_version
end

#variantString

Optional. The variant of the CPU in the image, for example v7 to specify ARMv7 when architecture is arm. Corresponds to the JSON property variant

Returns:

  • (String)


1276
1277
1278
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1276

def variant
  @variant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1283
1284
1285
1286
1287
1288
1289
1290
1291
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1283

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @digest = args[:digest] if args.key?(:digest)
  @media_type = args[:media_type] if args.key?(:media_type)
  @os = args[:os] if args.key?(:os)
  @os_features = args[:os_features] if args.key?(:os_features)
  @os_version = args[:os_version] if args.key?(:os_version)
  @variant = args[:variant] if args.key?(:variant)
end