Class: Google::Apis::ArtifactregistryV1::ImageManifest
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::ImageManifest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
Details of a single image manifest within a multi-arch image.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Optional.
-
#digest ⇒ String
Optional.
-
#media_type ⇒ String
Optional.
-
#os ⇒ String
Optional.
-
#os_features ⇒ Array<String>
Optional.
-
#os_version ⇒ String
Optional.
-
#variant ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageManifest
constructor
A new instance of ImageManifest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageManifest
Returns a new instance of ImageManifest.
1278 1279 1280 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1278 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Optional. The CPU architecture of the image. Values are provided by the Docker
client and are not validated by Artifact Registry. Example values include "
amd64", "arm64", "ppc64le", "s390x", "riscv64", "mips64le", etc.
Corresponds to the JSON property architecture
1240 1241 1242 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1240 def architecture @architecture end |
#digest ⇒ String
Optional. The manifest digest, in the format "sha256:".
Corresponds to the JSON property digest
1245 1246 1247 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1245 def digest @digest end |
#media_type ⇒ String
Optional. The media type of the manifest, e.g., "application/vnd.docker.
distribution.manifest.v2+json"
Corresponds to the JSON property mediaType
1251 1252 1253 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1251 def media_type @media_type end |
#os ⇒ String
Optional. The operating system of the image. Values are provided by the Docker
client and are not validated by Artifact Registry. Example values include "
linux", "windows", "darwin", "aix", etc.
Corresponds to the JSON property os
1258 1259 1260 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1258 def os @os end |
#os_features ⇒ Array<String>
Optional. The required OS features for the image, for example on Windows
win32k.
Corresponds to the JSON property osFeatures
1264 1265 1266 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1264 def os_features @os_features end |
#os_version ⇒ String
Optional. The OS version of the image, for example on Windows 10.0.14393.1066
.
Corresponds to the JSON property osVersion
1270 1271 1272 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1270 def os_version @os_version end |
#variant ⇒ String
Optional. The variant of the CPU in the image, for example v7 to specify
ARMv7 when architecture is arm.
Corresponds to the JSON property variant
1276 1277 1278 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1276 def variant @variant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1283 1284 1285 1286 1287 1288 1289 1290 1291 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1283 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @digest = args[:digest] if args.key?(:digest) @media_type = args[:media_type] if args.key?(:media_type) @os = args[:os] if args.key?(:os) @os_features = args[:os_features] if args.key?(:os_features) @os_version = args[:os_version] if args.key?(:os_version) @variant = args[:variant] if args.key?(:variant) end |