Class: Google::Apis::ArtifactregistryV1::ImportAptArtifactsErrorInfo
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::ImportAptArtifactsErrorInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
Error information explaining why a package was not imported.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ArtifactregistryV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#gcs_source ⇒ Google::Apis::ArtifactregistryV1::ImportAptArtifactsGcsSource
Google Cloud Storage location where the artifacts currently reside.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportAptArtifactsErrorInfo
constructor
A new instance of ImportAptArtifactsErrorInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportAptArtifactsErrorInfo
Returns a new instance of ImportAptArtifactsErrorInfo.
1380 1381 1382 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1380 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ArtifactregistryV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1373 1374 1375 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1373 def error @error end |
#gcs_source ⇒ Google::Apis::ArtifactregistryV1::ImportAptArtifactsGcsSource
Google Cloud Storage location where the artifacts currently reside.
Corresponds to the JSON property gcsSource
1378 1379 1380 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1378 def gcs_source @gcs_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1385 1386 1387 1388 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1385 def update!(**args) @error = args[:error] if args.key?(:error) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) end |