Class: Google::Apis::ArtifactregistryV1::ImportAptArtifactsErrorInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

Error information explaining why a package was not imported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportAptArtifactsErrorInfo

Returns a new instance of ImportAptArtifactsErrorInfo.



1313
1314
1315
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1313

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ArtifactregistryV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1306
1307
1308
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1306

def error
  @error
end

#gcs_sourceGoogle::Apis::ArtifactregistryV1::ImportAptArtifactsGcsSource

Google Cloud Storage location where the artifacts currently reside. Corresponds to the JSON property gcsSource



1311
1312
1313
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1311

def gcs_source
  @gcs_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1318
1319
1320
1321
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1318

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
end