Class: Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsErrorInfo
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsErrorInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
Error information explaining why a package was not imported.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ArtifactregistryV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#gcs_source ⇒ Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsGcsSource
Google Cloud Storage location where the artifacts currently reside.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportGoogetArtifactsErrorInfo
constructor
A new instance of ImportGoogetArtifactsErrorInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportGoogetArtifactsErrorInfo
Returns a new instance of ImportGoogetArtifactsErrorInfo.
1493 1494 1495 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ArtifactregistryV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1486 1487 1488 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1486 def error @error end |
#gcs_source ⇒ Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsGcsSource
Google Cloud Storage location where the artifacts currently reside.
Corresponds to the JSON property gcsSource
1491 1492 1493 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1491 def gcs_source @gcs_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1498 1499 1500 1501 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1498 def update!(**args) @error = args[:error] if args.key?(:error) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) end |