Class: Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsErrorInfo
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsErrorInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
Error information explaining why a package was not imported.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ArtifactregistryV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#gcs_source ⇒ Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsGcsSource
Google Cloud Storage location where the artifacts currently reside.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportGoogetArtifactsErrorInfo
constructor
A new instance of ImportGoogetArtifactsErrorInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportGoogetArtifactsErrorInfo
Returns a new instance of ImportGoogetArtifactsErrorInfo.
1439 1440 1441 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ArtifactregistryV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1432 1433 1434 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1432 def error @error end |
#gcs_source ⇒ Google::Apis::ArtifactregistryV1::ImportGoogetArtifactsGcsSource
Google Cloud Storage location where the artifacts currently reside.
Corresponds to the JSON property gcsSource
1437 1438 1439 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1437 def gcs_source @gcs_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1444 1445 1446 1447 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1444 def update!(**args) @error = args[:error] if args.key?(:error) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) end |