Class: Google::Apis::ArtifactregistryV1::ImportYumArtifactsErrorInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

Error information explaining why a package was not imported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportYumArtifactsErrorInfo

Returns a new instance of ImportYumArtifactsErrorInfo.



1539
1540
1541
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ArtifactregistryV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1532
1533
1534
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1532

def error
  @error
end

#gcs_sourceGoogle::Apis::ArtifactregistryV1::ImportYumArtifactsGcsSource

Google Cloud Storage location where the artifacts currently reside. Corresponds to the JSON property gcsSource



1537
1538
1539
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1537

def gcs_source
  @gcs_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1544
1545
1546
1547
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1544

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
end