Class: Google::Apis::ArtifactregistryV1::ListPrewarmedArtifactsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::ListPrewarmedArtifactsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
The response for listing artifacts for streaming.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token to retrieve the next page of prewarmed artifacts, or empty if there are no more streamings to return.
-
#prewarmed_artifacts ⇒ Array<Google::Apis::ArtifactregistryV1::PrewarmedArtifact>
The prewarmed artifacts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPrewarmedArtifactsResponse
constructor
A new instance of ListPrewarmedArtifactsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPrewarmedArtifactsResponse
Returns a new instance of ListPrewarmedArtifactsResponse.
1925 1926 1927 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token to retrieve the next page of prewarmed artifacts, or empty if there
are no more streamings to return.
Corresponds to the JSON property nextPageToken
1918 1919 1920 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1918 def next_page_token @next_page_token end |
#prewarmed_artifacts ⇒ Array<Google::Apis::ArtifactregistryV1::PrewarmedArtifact>
The prewarmed artifacts.
Corresponds to the JSON property prewarmedArtifacts
1923 1924 1925 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1923 def prewarmed_artifacts @prewarmed_artifacts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1930 1931 1932 1933 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 1930 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @prewarmed_artifacts = args[:prewarmed_artifacts] if args.key?(:prewarmed_artifacts) end |