Class: Google::Apis::ArtifactregistryV1::NpmRepository
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::NpmRepository
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
Configuration for a Npm remote repository.
Instance Attribute Summary collapse
-
#custom_repository ⇒ Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigNpmRepositoryCustomRepository
Customer-specified publicly available remote repository.
-
#public_repository ⇒ String
One of the publicly available Npm repositories supported by Artifact Registry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NpmRepository
constructor
A new instance of NpmRepository.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NpmRepository
Returns a new instance of NpmRepository.
2201 2202 2203 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_repository ⇒ Google::Apis::ArtifactregistryV1::GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigNpmRepositoryCustomRepository
Customer-specified publicly available remote repository.
Corresponds to the JSON property customRepository
2194 2195 2196 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2194 def custom_repository @custom_repository end |
#public_repository ⇒ String
One of the publicly available Npm repositories supported by Artifact Registry.
Corresponds to the JSON property publicRepository
2199 2200 2201 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2199 def public_repository @public_repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2206 2207 2208 2209 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2206 def update!(**args) @custom_repository = args[:custom_repository] if args.key?(:custom_repository) @public_repository = args[:public_repository] if args.key?(:public_repository) end |