Class: Google::Apis::ArtifactregistryV1::PrewarmArtifactRequest
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::PrewarmArtifactRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
The request for prewarming an artifact for streaming.
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Optional.
-
#platform ⇒ Google::Apis::ArtifactregistryV1::PrewarmPlatform
The platform (architecture and OS) of the image.
-
#retention_days ⇒ Fixnum
Optional.
-
#stream_location ⇒ String
Optional.
-
#tag ⇒ String
Optional.
-
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrewarmArtifactRequest
constructor
A new instance of PrewarmArtifactRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrewarmArtifactRequest
Returns a new instance of PrewarmArtifactRequest.
2582 2583 2584 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Optional. If true, old artifact will be evicted to make room for the new
artifact.
Corresponds to the JSON property force
2549 2550 2551 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2549 def force @force end |
#platform ⇒ Google::Apis::ArtifactregistryV1::PrewarmPlatform
The platform (architecture and OS) of the image. This is a sub-message.
Corresponds to the JSON property platform
2555 2556 2557 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2555 def platform @platform end |
#retention_days ⇒ Fixnum
Optional. The retention days of the prewarmed artifact. If not specified, the
artifact will be cached for 3 days.
Corresponds to the JSON property retentionDays
2561 2562 2563 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2561 def retention_days @retention_days end |
#stream_location ⇒ String
Optional. The location to cache the artifact in. If not specified, the
artifact will be cached in the same location as the artifact. multi-region is
not supported for this field.
Corresponds to the JSON property streamLocation
2568 2569 2570 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2568 def stream_location @stream_location end |
#tag ⇒ String
Optional. The artifact tag Format:projects/project/locations/location/
repositories/repository/packages/package/tags/tag
Corresponds to the JSON property tag
2574 2575 2576 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2574 def tag @tag end |
#version ⇒ String
Optional. The artifact version Format: projects/project/locations/location/
repositories/repository/packages/package/versions/version
Corresponds to the JSON property version
2580 2581 2582 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2580 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2587 2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2587 def update!(**args) @force = args[:force] if args.key?(:force) @platform = args[:platform] if args.key?(:platform) @retention_days = args[:retention_days] if args.key?(:retention_days) @stream_location = args[:stream_location] if args.key?(:stream_location) @tag = args[:tag] if args.key?(:tag) @version = args[:version] if args.key?(:version) end |