Class: Google::Apis::ArtifactregistryV1::ProjectConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

The Artifact Registry logging configurations that apply to a Project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectConfig

Returns a new instance of ProjectConfig.



2476
2477
2478
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The name of the project's configuration. Always of the form: projects/project/locations/location/projectConfig Corresponds to the JSON property name

Returns:

  • (String)


2469
2470
2471
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2469

def name
  @name
end

#platform_logs_configGoogle::Apis::ArtifactregistryV1::PlatformLogsConfig

The platform logs config for a project or a repository. Corresponds to the JSON property platformLogsConfig



2474
2475
2476
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2474

def platform_logs_config
  @platform_logs_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2481
2482
2483
2484
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2481

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @platform_logs_config = args[:platform_logs_config] if args.key?(:platform_logs_config)
end