Class: Google::Apis::ArtifactregistryV1::Repository

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

A Repository for storing artifacts with a specific format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Repository

Returns a new instance of Repository.



2808
2809
2810
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cleanup_policiesHash<String,Google::Apis::ArtifactregistryV1::CleanupPolicy>

Optional. Cleanup policies for this repository. Cleanup policies indicate when certain package versions can be automatically deleted. Map keys are policy IDs supplied by users during policy creation. They must unique within a repository and be under 128 characters in length. Corresponds to the JSON property cleanupPolicies



2686
2687
2688
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2686

def cleanup_policies
  @cleanup_policies
end

#cleanup_policy_dry_runBoolean Also known as: cleanup_policy_dry_run?

Optional. If true, the cleanup pipeline is prevented from deleting versions in this repository. Corresponds to the JSON property cleanupPolicyDryRun

Returns:

  • (Boolean)


2692
2693
2694
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2692

def cleanup_policy_dry_run
  @cleanup_policy_dry_run
end

#create_timeString

Output only. The time when the repository was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2698
2699
2700
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2698

def create_time
  @create_time
end

#descriptionString

The user-provided description of the repository. Corresponds to the JSON property description

Returns:

  • (String)


2703
2704
2705
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2703

def description
  @description
end

#disallow_unspecified_modeBoolean Also known as: disallow_unspecified_mode?

Optional. If this is true, an unspecified repo type will be treated as error rather than defaulting to standard. Corresponds to the JSON property disallowUnspecifiedMode

Returns:

  • (Boolean)


2709
2710
2711
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2709

def disallow_unspecified_mode
  @disallow_unspecified_mode
end

#docker_configGoogle::Apis::ArtifactregistryV1::DockerRepositoryConfig

DockerRepositoryConfig is docker related repository details. Provides additional configuration details for repositories of the docker format type. Corresponds to the JSON property dockerConfig



2716
2717
2718
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2716

def docker_config
  @docker_config
end

#formatString

Optional. The format of packages that are stored in the repository. Corresponds to the JSON property format

Returns:

  • (String)


2721
2722
2723
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2721

def format
  @format
end

#kms_key_nameString

The Cloud KMS resource name of the customer managed encryption key that's used to encrypt the contents of the Repository. Has the form: projects/my-project/ locations/my-region/keyRings/my-kr/cryptoKeys/my-key. This value may not be changed after the Repository has been created. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


2729
2730
2731
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2729

def kms_key_name
  @kms_key_name
end

#labelsHash<String,String>

Labels with user-defined metadata. This field may contain up to 64 entries. Label keys and values may be no longer than 63 characters. Label keys must begin with a lowercase letter and may only contain lowercase letters, numeric characters, underscores, and dashes. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2737
2738
2739
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2737

def labels
  @labels
end

#maven_configGoogle::Apis::ArtifactregistryV1::MavenRepositoryConfig

MavenRepositoryConfig is maven related repository details. Provides additional configuration details for repositories of the maven format type. Corresponds to the JSON property mavenConfig



2743
2744
2745
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2743

def maven_config
  @maven_config
end

#modeString

Optional. The mode of the repository. Corresponds to the JSON property mode

Returns:

  • (String)


2748
2749
2750
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2748

def mode
  @mode
end

#nameString

The name of the repository, for example: projects/p1/locations/us-central1/ repositories/repo1. For each location in a project, repository names must be unique. Corresponds to the JSON property name

Returns:

  • (String)


2755
2756
2757
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2755

def name
  @name
end

#platform_logs_configGoogle::Apis::ArtifactregistryV1::PlatformLogsConfig

The platform logs config for a project or a repository. Corresponds to the JSON property platformLogsConfig



2760
2761
2762
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2760

def platform_logs_config
  @platform_logs_config
end

#registry_uriString

Output only. The repository endpoint, for example: us-docker.pkg.dev/my-proj/ my-repo. Corresponds to the JSON property registryUri

Returns:

  • (String)


2766
2767
2768
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2766

def registry_uri
  @registry_uri
end

#remote_repository_configGoogle::Apis::ArtifactregistryV1::RemoteRepositoryConfig

Remote repository configuration. Corresponds to the JSON property remoteRepositoryConfig



2771
2772
2773
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2771

def remote_repository_config
  @remote_repository_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Whether or not this repository satisfies PZI. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


2776
2777
2778
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2776

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Whether or not this repository satisfies PZS. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


2782
2783
2784
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2782

def satisfies_pzs
  @satisfies_pzs
end

#size_bytesFixnum

Output only. The size, in bytes, of all artifact storage in this repository. Repositories that are generally available or in public preview use this to calculate storage costs. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


2790
2791
2792
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2790

def size_bytes
  @size_bytes
end

#update_timeString

Output only. The time when the repository was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2795
2796
2797
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2795

def update_time
  @update_time
end

#virtual_repository_configGoogle::Apis::ArtifactregistryV1::VirtualRepositoryConfig

Virtual repository configuration. Corresponds to the JSON property virtualRepositoryConfig



2800
2801
2802
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2800

def virtual_repository_config
  @virtual_repository_config
end

#vulnerability_scanning_configGoogle::Apis::ArtifactregistryV1::VulnerabilityScanningConfig

Config on whether to perform vulnerability scanning for resources in this repository, as well as output fields describing current state. Corresponds to the JSON property vulnerabilityScanningConfig



2806
2807
2808
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2806

def vulnerability_scanning_config
  @vulnerability_scanning_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 2813

def update!(**args)
  @cleanup_policies = args[:cleanup_policies] if args.key?(:cleanup_policies)
  @cleanup_policy_dry_run = args[:cleanup_policy_dry_run] if args.key?(:cleanup_policy_dry_run)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disallow_unspecified_mode = args[:disallow_unspecified_mode] if args.key?(:disallow_unspecified_mode)
  @docker_config = args[:docker_config] if args.key?(:docker_config)
  @format = args[:format] if args.key?(:format)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @labels = args[:labels] if args.key?(:labels)
  @maven_config = args[:maven_config] if args.key?(:maven_config)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @platform_logs_config = args[:platform_logs_config] if args.key?(:platform_logs_config)
  @registry_uri = args[:registry_uri] if args.key?(:registry_uri)
  @remote_repository_config = args[:remote_repository_config] if args.key?(:remote_repository_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @update_time = args[:update_time] if args.key?(:update_time)
  @virtual_repository_config = args[:virtual_repository_config] if args.key?(:virtual_repository_config)
  @vulnerability_scanning_config = args[:vulnerability_scanning_config] if args.key?(:vulnerability_scanning_config)
end