Class: Google::Apis::ArtifactregistryV1::Version
- Inherits:
-
Object
- Object
- Google::Apis::ArtifactregistryV1::Version
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb
Overview
The body of a version resource. A version resource represents a collection of components, such as files and other data. This may correspond to a version in many package management schemes.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
The time when the version was created.
-
#description ⇒ String
Optional.
-
#metadata ⇒ Hash<String,Object>
Output only.
-
#name ⇒ String
The name of the version, for example:
projects/p1/locations/us-central1/ repositories/repo1/packages/pkg1/versions/art1. -
#related_tags ⇒ Array<Google::Apis::ArtifactregistryV1::Tag>
Output only.
-
#update_time ⇒ String
The time when the version was last updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Version
constructor
A new instance of Version.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Version
Returns a new instance of Version.
3492 3493 3494 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Client specified annotations.
Corresponds to the JSON property annotations
3455 3456 3457 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3455 def annotations @annotations end |
#create_time ⇒ String
The time when the version was created.
Corresponds to the JSON property createTime
3460 3461 3462 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3460 def create_time @create_time end |
#description ⇒ String
Optional. Description of the version, as specified in its metadata.
Corresponds to the JSON property description
3465 3466 3467 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3465 def description @description end |
#metadata ⇒ Hash<String,Object>
Output only. Repository-specific Metadata stored against this version. The
fields returned are defined by the underlying repository-specific resource.
Currently, the resources could be: DockerImage MavenArtifact
Corresponds to the JSON property metadata
3472 3473 3474 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3472 def @metadata end |
#name ⇒ String
The name of the version, for example: projects/p1/locations/us-central1/
repositories/repo1/packages/pkg1/versions/art1. If the package or version ID
parts contain slashes, the slashes are escaped.
Corresponds to the JSON property name
3479 3480 3481 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3479 def name @name end |
#related_tags ⇒ Array<Google::Apis::ArtifactregistryV1::Tag>
Output only. A list of related tags. Will contain up to 100 tags that
reference this version.
Corresponds to the JSON property relatedTags
3485 3486 3487 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3485 def @related_tags end |
#update_time ⇒ String
The time when the version was last updated.
Corresponds to the JSON property updateTime
3490 3491 3492 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3490 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3497 3498 3499 3500 3501 3502 3503 3504 3505 |
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3497 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @related_tags = args[:related_tags] if args.key?(:related_tags) @update_time = args[:update_time] if args.key?(:update_time) end |