Class: Google::Apis::ArtifactregistryV1::VulnerabilityScanningConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/artifactregistry_v1/classes.rb,
lib/google/apis/artifactregistry_v1/representations.rb,
lib/google/apis/artifactregistry_v1/representations.rb

Overview

Config on whether to perform vulnerability scanning for resources in this repository, as well as output fields describing current state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityScanningConfig

Returns a new instance of VulnerabilityScanningConfig.



3634
3635
3636
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enablement_configString

Optional. Config for whether this repository has vulnerability scanning disabled. Corresponds to the JSON property enablementConfig

Returns:

  • (String)


3616
3617
3618
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3616

def enablement_config
  @enablement_config
end

#enablement_stateString

Output only. State of feature enablement, combining repository enablement config and API enablement state. Corresponds to the JSON property enablementState

Returns:

  • (String)


3622
3623
3624
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3622

def enablement_state
  @enablement_state
end

#enablement_state_reasonString

Output only. Reason for the repository state. Corresponds to the JSON property enablementStateReason

Returns:

  • (String)


3627
3628
3629
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3627

def enablement_state_reason
  @enablement_state_reason
end

#last_enable_timeString

Output only. The last time this repository config was enabled. Corresponds to the JSON property lastEnableTime

Returns:

  • (String)


3632
3633
3634
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3632

def last_enable_time
  @last_enable_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3639
3640
3641
3642
3643
3644
# File 'lib/google/apis/artifactregistry_v1/classes.rb', line 3639

def update!(**args)
  @enablement_config = args[:enablement_config] if args.key?(:enablement_config)
  @enablement_state = args[:enablement_state] if args.key?(:enablement_state)
  @enablement_state_reason = args[:enablement_state_reason] if args.key?(:enablement_state_reason)
  @last_enable_time = args[:last_enable_time] if args.key?(:last_enable_time)
end